@@ -1,18 +1,20 @@
 # This relies on each of the submodules having an __all__ variable.
 
-__version__ = '0.9.0'
+__version__ = '0.9.1'
 
 
 from .protocol import *
 from .connector import *
 from .client import *
 from .errors import *
+from .helpers import *
 from .parsers import *
 from .streams import *
 
 
 __all__ = (client.__all__ +
            errors.__all__ +
+           helpers.__all__ +
            parsers.__all__ +
            protocol.__all__ +
            connector.__all__ +
