@@ -1,30 +1,43 @@
 """Various helper functions"""
+__all__ = ['BasicAuth', 'FormData', 'parse_mimetype']
+
 import base64
 import io
 import os
 import uuid
 import urllib.parse
 from collections import namedtuple
+from wsgiref.handlers import format_date_time
+
+from . import multidict
 
 
 class BasicAuth(namedtuple('BasicAuth', ['login', 'password', 'encoding'])):
+    """Http basic authentication helper.
+
+    :param str login: Login
+    :param str password: Password
+    :param str encoding: (optional) encoding ('latin1' by default)
+    """
 
     def __new__(cls, login, password='', encoding='latin1'):
         if login is None:
             raise ValueError('None is not allowed as login value')
 
         if password is None:
-            raise ValueError('None is not allowed as login value')
+            raise ValueError('None is not allowed as password value')
 
         return super().__new__(cls, login, password, encoding)
 
     def encode(self):
+        """Encode credentials."""
         creds = ('%s:%s' % (self.login, self.password)).encode(self.encoding)
         return 'Basic %s' % base64.b64encode(creds).decode(self.encoding)
 
 
 class FormData:
-    """Generate multipart/form-data body."""
+    """Helper class for multipart/form-data and
+    application/x-www-form-urlencoded body generation."""
 
     def __init__(self, fields):
         self._fields = []
@@ -54,12 +67,19 @@ class FormData:
         self._fields.append((name, value, contenttype, filename))
 
     def add_fields(self, *fields):
-        for rec in fields:
+        to_add = list(fields)
+
+        while to_add:
+            rec = to_add.pop(0)
+
             if isinstance(rec, io.IOBase):
                 k = guess_filename(rec, 'unknown')
                 self.add_field(k, rec)
                 self._has_io = True
 
+            elif isinstance(rec, multidict.MultiDict):
+                to_add.extend(rec.items(getall=True))
+
             elif len(rec) == 1:
                 k = guess_filename(rec[0], 'unknown')
                 self.add_field(k, rec[0])
@@ -134,13 +154,18 @@ class FormData:
 
 
 def parse_mimetype(mimetype):
-    """Parses a MIME type into it components.
+    """Parses a MIME type into its components.
 
     :param str mimetype: MIME type
 
     :returns: 4 element tuple for MIME type, subtype, suffix and parameters
     :rtype: tuple
 
+    Example:
+
+    >>> parse_mimetype('text/html; charset=utf-8')
+    ('text', 'html', '', {'charset': 'utf-8'})
+
     """
     if not mimetype:
         return '', '', '', {}
@@ -176,3 +201,60 @@ def guess_filename(obj, default=None):
     if name and name[0] != '<' and name[-1] != '>':
         return os.path.split(name)[-1]
     return default
+
+
+def atoms(message, environ, response, request_time):
+    """Gets atoms for log formatting."""
+    if message:
+        r = '{} {} HTTP/{}.{}'.format(
+            message.method, message.path,
+            message.version[0], message.version[1])
+    else:
+        r = ''
+
+    atoms = {
+        'h': environ.get('REMOTE_ADDR', '-'),
+        'l': '-',
+        'u': '-',
+        't': format_date_time(None),
+        'r': r,
+        's': str(response.status),
+        'b': str(response.output_length),
+        'f': environ.get('HTTP_REFERER', '-'),
+        'a': environ.get('HTTP_USER_AGENT', '-'),
+        'T': str(int(request_time)),
+        'D': str(request_time).split('.', 1)[-1][:5],
+        'p': "<%s>" % os.getpid()
+    }
+
+    return atoms
+
+
+class SafeAtoms(dict):
+    """Copy from gunicorn"""
+
+    def __init__(self, atoms, i_headers, o_headers):
+        dict.__init__(self)
+
+        self._i_headers = i_headers
+        self._o_headers = o_headers
+
+        for key, value in atoms.items():
+            self[key] = value.replace('"', '\\"')
+
+    def __getitem__(self, k):
+        if k.startswith('{'):
+            if k.endswith('}i'):
+                headers = self._i_headers
+            elif k.endswith('}o'):
+                headers = self._o_headers
+            else:
+                headers = None
+
+            if headers is not None:
+                return headers.get(k[1:-2], '-')
+
+        if k in self:
+            return super(SafeAtoms, self).__getitem__(k)
+        else:
+            return '-'
