@@ -2,6 +2,7 @@ import unittest
 import unittest.mock
 
 from aiohttp import helpers
+from aiohttp import multidict
 
 
 class HelpersTests(unittest.TestCase):
@@ -52,3 +53,22 @@ class HelpersTests(unittest.TestCase):
         self.assertEqual(auth.login, 'nkim')
         self.assertEqual(auth.password, 'pwd')
         self.assertEqual(auth.encode(), 'Basic bmtpbTpwd2Q=')
+
+
+class SafeAtomsTests(unittest.TestCase):
+
+    def test_get_non_existing(self):
+        atoms = helpers.SafeAtoms(
+            {}, multidict.MultiDict(), multidict.MultiDict())
+        self.assertEqual(atoms['unknown'], '-')
+
+    def test_get_lower(self):
+        i_headers = multidict.MultiDict([('test', '123')])
+        o_headers = multidict.MultiDict([('TEST', '123')])
+
+        atoms = helpers.SafeAtoms({}, i_headers, o_headers)
+        self.assertEqual(atoms['{test}i'], '123')
+        self.assertEqual(atoms['{test}o'], '-')
+        self.assertEqual(atoms['{TEST}o'], '123')
+        self.assertEqual(atoms['{UNKNOWN}o'], '-')
+        self.assertEqual(atoms['{UNKNOWN}'], '-')
