@@ -19,8 +19,8 @@ class ParseHeadersTests(unittest.TestCase):
         self.parser = protocol.HttpParser(8190, 32768, 8190)
 
     def test_parse_headers(self):
-        hdrs = ('', 'test: line\r\n', ' continue\r\n',
-                'test2: data\r\n', '\r\n')
+        hdrs = ('', 'test: line', ' continue',
+                'test2: data', '', '')
 
         headers, close, compression = self.parser.parse_headers(hdrs)
 
@@ -31,8 +31,8 @@ class ParseHeadersTests(unittest.TestCase):
 
     def test_parse_headers_multi(self):
         hdrs = ('',
-                'Set-Cookie: c1=cookie1\r\n',
-                'Set-Cookie: c2=cookie2\r\n', '\r\n')
+                'Set-Cookie: c1=cookie1',
+                'Set-Cookie: c2=cookie2', '')
 
         headers, close, compression = self.parser.parse_headers(hdrs)
 
@@ -44,32 +44,32 @@ class ParseHeadersTests(unittest.TestCase):
 
     def test_conn_close(self):
         headers, close, compression = self.parser.parse_headers(
-            ['', 'connection: close\r\n', '\r\n'])
+            ['', 'connection: close', ''])
         self.assertTrue(close)
 
     def test_conn_keep_alive(self):
         headers, close, compression = self.parser.parse_headers(
-            ['', 'connection: keep-alive\r\n', '\r\n'])
+            ['', 'connection: keep-alive', ''])
         self.assertFalse(close)
 
     def test_conn_other(self):
         headers, close, compression = self.parser.parse_headers(
-            ['', 'connection: test\r\n', '\r\n'])
+            ['', 'connection: test', '', ''])
         self.assertIsNone(close)
 
     def test_compression_gzip(self):
         headers, close, compression = self.parser.parse_headers(
-            ['', 'content-encoding: gzip\r\n', '\r\n'])
+            ['', 'content-encoding: gzip', '', ''])
         self.assertEqual('gzip', compression)
 
     def test_compression_deflate(self):
         headers, close, compression = self.parser.parse_headers(
-            ['', 'content-encoding: deflate\r\n', '\r\n'])
+            ['', 'content-encoding: deflate', '', ''])
         self.assertEqual('deflate', compression)
 
     def test_compression_unknown(self):
         headers, close, compression = self.parser.parse_headers(
-            ['', 'content-encoding: compress\r\n', '\r\n'])
+            ['', 'content-encoding: compress', '', ''])
         self.assertIsNone(compression)
 
     def test_max_field_size(self):
@@ -103,7 +103,7 @@ class DeflateBufferTests(unittest.TestCase):
         asyncio.set_event_loop(None)
 
     def test_feed_data(self):
-        buf = aiohttp.DataQueue(self.stream)
+        buf = aiohttp.FlowControlDataQueue(self.stream)
         dbuf = protocol.DeflateBuffer(buf, 'deflate')
 
         dbuf.zlib = unittest.mock.Mock()
@@ -113,7 +113,7 @@ class DeflateBufferTests(unittest.TestCase):
         self.assertEqual([b'line'], list(buf._buffer))
 
     def test_feed_data_err(self):
-        buf = aiohttp.DataQueue(self.stream)
+        buf = aiohttp.FlowControlDataQueue(self.stream)
         dbuf = protocol.DeflateBuffer(buf, 'deflate')
 
         exc = ValueError()
@@ -123,7 +123,7 @@ class DeflateBufferTests(unittest.TestCase):
         self.assertRaises(errors.IncompleteRead, dbuf.feed_data, b'data')
 
     def test_feed_eof(self):
-        buf = aiohttp.DataQueue(self.stream)
+        buf = aiohttp.FlowControlDataQueue(self.stream)
         dbuf = protocol.DeflateBuffer(buf, 'deflate')
 
         dbuf.zlib = unittest.mock.Mock()
@@ -134,7 +134,7 @@ class DeflateBufferTests(unittest.TestCase):
         self.assertTrue(buf._eof)
 
     def test_feed_eof_err(self):
-        buf = aiohttp.DataQueue(self.stream)
+        buf = aiohttp.FlowControlDataQueue(self.stream)
         dbuf = protocol.DeflateBuffer(buf, 'deflate')
 
         dbuf.zlib = unittest.mock.Mock()
@@ -151,7 +151,7 @@ class ParsePayloadTests(unittest.TestCase):
         asyncio.set_event_loop(None)
 
     def test_parse_eof_payload(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(None).parse_eof_payload(out, buf)
         next(p)
@@ -164,7 +164,7 @@ class ParsePayloadTests(unittest.TestCase):
         self.assertEqual([b'data'], list(out._buffer))
 
     def test_parse_length_payload(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(None).parse_length_payload(out, buf, 4)
         next(p)
@@ -180,7 +180,7 @@ class ParsePayloadTests(unittest.TestCase):
         self.assertEqual(b'line', bytes(buf))
 
     def test_parse_length_payload_eof(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(None).parse_length_payload(out, buf, 4)
         next(p)
@@ -189,7 +189,7 @@ class ParsePayloadTests(unittest.TestCase):
             errors.IncompleteRead, p.throw, aiohttp.EofStream)
 
     def test_parse_chunked_payload(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(None).parse_chunked_payload(out, buf)
         next(p)
@@ -201,7 +201,7 @@ class ParsePayloadTests(unittest.TestCase):
         self.assertEqual(b'', bytes(buf))
 
     def test_parse_chunked_payload_chunks(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(None).parse_chunked_payload(out, buf)
         next(p)
@@ -214,7 +214,7 @@ class ParsePayloadTests(unittest.TestCase):
         self.assertEqual(b'dataline', b''.join(out._buffer))
 
     def test_parse_chunked_payload_incomplete(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(None).parse_chunked_payload(out, buf)
         next(p)
@@ -222,7 +222,7 @@ class ParsePayloadTests(unittest.TestCase):
         self.assertRaises(errors.ConnectionError, p.throw, aiohttp.EofStream)
 
     def test_parse_chunked_payload_extension(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(None).parse_chunked_payload(out, buf)
         next(p)
@@ -233,7 +233,7 @@ class ParsePayloadTests(unittest.TestCase):
         self.assertEqual(b'dataline', b''.join(out._buffer))
 
     def test_parse_chunked_payload_size_error(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(None).parse_chunked_payload(out, buf)
         next(p)
@@ -243,7 +243,7 @@ class ParsePayloadTests(unittest.TestCase):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
             multidict.MultiDict([('CONTENT-LENGTH', 'qwe')]), None, None)
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
         self.assertRaises(errors.InvalidHeader, next, p)
@@ -252,7 +252,7 @@ class ParsePayloadTests(unittest.TestCase):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
             multidict.MultiDict([('CONTENT-LENGTH', '-1')]), None, None)
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
         self.assertRaises(errors.InvalidHeader, next, p)
@@ -261,7 +261,7 @@ class ParsePayloadTests(unittest.TestCase):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
             multidict.MultiDict([('CONTENT-LENGTH', '2')]), None, None)
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
         next(p)
@@ -276,7 +276,7 @@ class ParsePayloadTests(unittest.TestCase):
     def test_http_payload_parser_no_length(self):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1), multidict.MultiDict(), None, None)
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg, readall=False)(out, buf)
         self.assertRaises(StopIteration, next, p)
@@ -292,7 +292,7 @@ class ParsePayloadTests(unittest.TestCase):
             multidict.MultiDict([('CONTENT-LENGTH', len(self._COMPRESSED))]),
             None, 'deflate')
 
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
         next(p)
@@ -305,7 +305,7 @@ class ParsePayloadTests(unittest.TestCase):
             multidict.MultiDict([('CONTENT-LENGTH', len(self._COMPRESSED))]),
             None, 'deflate')
 
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg, compression=False)(out, buf)
         next(p)
@@ -316,7 +316,7 @@ class ParsePayloadTests(unittest.TestCase):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
             multidict.MultiDict([('SEC-WEBSOCKET-KEY1', '13')]), None, None)
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
         next(p)
@@ -328,7 +328,7 @@ class ParsePayloadTests(unittest.TestCase):
             'GET', '/', (1, 1),
             multidict.MultiDict([('TRANSFER-ENCODING', 'chunked')]),
             None, None)
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
         next(p)
@@ -339,7 +339,7 @@ class ParsePayloadTests(unittest.TestCase):
     def test_http_payload_parser_eof(self):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1), multidict.MultiDict(), None, None)
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg, readall=True)(out, buf)
         next(p)
@@ -352,7 +352,7 @@ class ParsePayloadTests(unittest.TestCase):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
             multidict.MultiDict([('CONTENT-LENGTH', '0')]), None, None)
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
         self.assertRaises(StopIteration, next, p)
@@ -366,7 +366,7 @@ class ParseRequestTests(unittest.TestCase):
         asyncio.set_event_loop(None)
 
     def test_http_request_parser_max_headers(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpRequestParser(8190, 20, 8190)(out, buf)
         next(p)
@@ -377,7 +377,7 @@ class ParseRequestTests(unittest.TestCase):
             b'get /path HTTP/1.1\r\ntest: line\r\ntest2: data\r\n\r\n')
 
     def test_http_request_parser(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpRequestParser()(out, buf)
         next(p)
@@ -392,7 +392,7 @@ class ParseRequestTests(unittest.TestCase):
 
     def test_http_request_parser_eof(self):
         # HttpRequestParser does fail on EofStream()
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpRequestParser()(out, buf)
         next(p)
@@ -404,7 +404,7 @@ class ParseRequestTests(unittest.TestCase):
         self.assertFalse(out._buffer)
 
     def test_http_request_parser_two_slashes(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpRequestParser()(out, buf)
         next(p)
@@ -417,7 +417,7 @@ class ParseRequestTests(unittest.TestCase):
             out._buffer[0])
 
     def test_http_request_parser_bad_status_line(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpRequestParser()(out, buf)
         next(p)
@@ -425,7 +425,7 @@ class ParseRequestTests(unittest.TestCase):
             errors.BadStatusLine, p.send, b'\r\n\r\n')
 
     def test_http_request_parser_bad_method(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpRequestParser()(out, buf)
         next(p)
@@ -434,7 +434,7 @@ class ParseRequestTests(unittest.TestCase):
             p.send, b'!12%()+=~$ /get HTTP/1.1\r\n\r\n')
 
     def test_http_request_parser_bad_version(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpRequestParser()(out, buf)
         next(p)
@@ -450,14 +450,14 @@ class ParseResponseTests(unittest.TestCase):
         asyncio.set_event_loop(None)
 
     def test_http_response_parser_bad_status_line(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpResponseParser()(out, buf)
         next(p)
         self.assertRaises(errors.BadStatusLine, p.send, b'\r\n\r\n')
 
     def test_http_response_parser_bad_status_line_too_long(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpResponseParser(
             max_headers=2, max_line_size=2)(out, buf)
@@ -466,7 +466,7 @@ class ParseResponseTests(unittest.TestCase):
             errors.LineTooLong, p.send, b'HTTP/1.1 200 Ok\r\n\r\n')
 
     def test_http_response_parser_bad_status_line_eof(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpResponseParser()(out, buf)
         next(p)
@@ -474,16 +474,16 @@ class ParseResponseTests(unittest.TestCase):
             errors.ConnectionError, p.throw, aiohttp.EofStream())
 
     def test_http_response_parser_bad_version(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpResponseParser()(out, buf)
         next(p)
         with self.assertRaises(errors.BadStatusLine) as cm:
             p.send(b'HT/11 200 Ok\r\n\r\n')
-        self.assertEqual('HT/11 200 Ok\r\n', cm.exception.args[0])
+        self.assertEqual('HT/11 200 Ok', cm.exception.args[0])
 
     def test_http_response_parser_no_reason(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpResponseParser()(out, buf)
         next(p)
@@ -497,7 +497,7 @@ class ParseResponseTests(unittest.TestCase):
         self.assertEqual(r, '')
 
     def test_http_response_parser_bad(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpResponseParser()(out, buf)
         next(p)
@@ -506,7 +506,7 @@ class ParseResponseTests(unittest.TestCase):
         self.assertIn('HTT/1', str(cm.exception))
 
     def test_http_response_parser_code_under_100(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpResponseParser()(out, buf)
         next(p)
@@ -515,7 +515,7 @@ class ParseResponseTests(unittest.TestCase):
         self.assertIn('HTTP/1.1 99 test', str(cm.exception))
 
     def test_http_response_parser_code_above_999(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpResponseParser()(out, buf)
         next(p)
@@ -524,7 +524,7 @@ class ParseResponseTests(unittest.TestCase):
         self.assertIn('HTTP/1.1 9999 test', str(cm.exception))
 
     def test_http_response_parser_code_not_int(self):
-        out = aiohttp.DataQueue(self.stream)
+        out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpResponseParser()(out, buf)
         next(p)
